# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

from influxdb_client.service._base_service import _BaseService


class InvokableScriptsService(_BaseService):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):  # noqa: E501,D401,D403
        """InvokableScriptsService - a operation defined in OpenAPI."""
        super().__init__(api_client)

    def delete_scripts_id(self, script_id, **kwargs):  # noqa: E501,D401,D403
        """Delete a script.

        Deletes a [script](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/) and all associated records.  #### Limitations  - You can delete only one script per request. - If the script ID you provide doesn't exist for the organization, InfluxDB responds with an HTTP `204` status code.  #### Related Guides  - [Invoke custom scripts](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_scripts_id(script_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str script_id: A script ID. Deletes the specified script. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_scripts_id_with_http_info(script_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_scripts_id_with_http_info(script_id, **kwargs)  # noqa: E501
            return data

    def delete_scripts_id_with_http_info(self, script_id, **kwargs):  # noqa: E501,D401,D403
        """Delete a script.

        Deletes a [script](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/) and all associated records.  #### Limitations  - You can delete only one script per request. - If the script ID you provide doesn't exist for the organization, InfluxDB responds with an HTTP `204` status code.  #### Related Guides  - [Invoke custom scripts](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_scripts_id_with_http_info(script_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str script_id: A script ID. Deletes the specified script. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        if not self._is_cloud_instance():
            from influxdb_client.client.warnings import CloudOnlyWarning
            CloudOnlyWarning.print_warning('InvokableScriptsService',
                                           'https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/')  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._delete_scripts_id_prepare(script_id, **kwargs)  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/scripts/{scriptID}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type=None,  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def delete_scripts_id_async(self, script_id, **kwargs):  # noqa: E501,D401,D403
        """Delete a script.

        Deletes a [script](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/) and all associated records.  #### Limitations  - You can delete only one script per request. - If the script ID you provide doesn't exist for the organization, InfluxDB responds with an HTTP `204` status code.  #### Related Guides  - [Invoke custom scripts](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/)
        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param str script_id: A script ID. Deletes the specified script. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        if not await self._is_cloud_instance_async():
            from influxdb_client.client.warnings import CloudOnlyWarning
            CloudOnlyWarning.print_warning('InvokableScriptsService',
                                           'https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/')  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._delete_scripts_id_prepare(script_id, **kwargs)  # noqa: E501

        return await self.api_client.call_api(
            '/api/v2/scripts/{scriptID}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type=None,  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _delete_scripts_id_prepare(self, script_id, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['script_id']  # noqa: E501
        self._check_operation_params('delete_scripts_id', all_params, local_var_params)
        # verify the required parameter 'script_id' is set
        if ('script_id' not in local_var_params or
                local_var_params['script_id'] is None):
            raise ValueError("Missing the required parameter `script_id` when calling `delete_scripts_id`")  # noqa: E501

        path_params = {}
        if 'script_id' in local_var_params:
            path_params['scriptID'] = local_var_params['script_id']  # noqa: E501

        query_params = []

        header_params = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params

    def get_scripts(self, **kwargs):  # noqa: E501,D401,D403
        """List scripts.

        Lists [scripts](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/).  #### Related guides  - [Invoke custom scripts](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_scripts(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The offset for pagination. The number of records to skip.  For more information about pagination parameters, see [Pagination]({{% INFLUXDB_DOCS_URL %}}/api/#tag/Pagination).
        :param int limit: The maximum number of scripts to return. Default is `100`.
        :param str name: The script name. Lists scripts with the specified name.
        :return: Scripts
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_scripts_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_scripts_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_scripts_with_http_info(self, **kwargs):  # noqa: E501,D401,D403
        """List scripts.

        Lists [scripts](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/).  #### Related guides  - [Invoke custom scripts](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_scripts_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The offset for pagination. The number of records to skip.  For more information about pagination parameters, see [Pagination]({{% INFLUXDB_DOCS_URL %}}/api/#tag/Pagination).
        :param int limit: The maximum number of scripts to return. Default is `100`.
        :param str name: The script name. Lists scripts with the specified name.
        :return: Scripts
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        if not self._is_cloud_instance():
            from influxdb_client.client.warnings import CloudOnlyWarning
            CloudOnlyWarning.print_warning('InvokableScriptsService',
                                           'https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/')  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_scripts_prepare(**kwargs)  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/scripts', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='Scripts',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def get_scripts_async(self, **kwargs):  # noqa: E501,D401,D403
        """List scripts.

        Lists [scripts](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/).  #### Related guides  - [Invoke custom scripts](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/)
        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param int offset: The offset for pagination. The number of records to skip.  For more information about pagination parameters, see [Pagination]({{% INFLUXDB_DOCS_URL %}}/api/#tag/Pagination).
        :param int limit: The maximum number of scripts to return. Default is `100`.
        :param str name: The script name. Lists scripts with the specified name.
        :return: Scripts
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        if not await self._is_cloud_instance_async():
            from influxdb_client.client.warnings import CloudOnlyWarning
            CloudOnlyWarning.print_warning('InvokableScriptsService',
                                           'https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/')  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_scripts_prepare(**kwargs)  # noqa: E501

        return await self.api_client.call_api(
            '/api/v2/scripts', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='Scripts',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _get_scripts_prepare(self, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['offset', 'limit', 'name']  # noqa: E501
        self._check_operation_params('get_scripts', all_params, local_var_params)

        if 'offset' in local_var_params and local_var_params['offset'] < 0:  # noqa: E501
            raise ValueError("Invalid value for parameter `offset` when calling `get_scripts`, must be a value greater than or equal to `0`")  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] > 500:  # noqa: E501
            raise ValueError("Invalid value for parameter `limit` when calling `get_scripts`, must be a value less than or equal to `500`")  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] < 0:  # noqa: E501
            raise ValueError("Invalid value for parameter `limit` when calling `get_scripts`, must be a value greater than or equal to `0`")  # noqa: E501
        path_params = {}

        query_params = []
        if 'offset' in local_var_params:
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'limit' in local_var_params:
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'name' in local_var_params:
            query_params.append(('name', local_var_params['name']))  # noqa: E501

        header_params = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params

    def get_scripts_id(self, script_id, **kwargs):  # noqa: E501,D401,D403
        """Retrieve a script.

        Retrieves a [script](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/).  #### Related Guides  - [Invoke custom scripts](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_scripts_id(script_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str script_id: A script ID. Retrieves the specified script. (required)
        :return: Script
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_scripts_id_with_http_info(script_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_scripts_id_with_http_info(script_id, **kwargs)  # noqa: E501
            return data

    def get_scripts_id_with_http_info(self, script_id, **kwargs):  # noqa: E501,D401,D403
        """Retrieve a script.

        Retrieves a [script](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/).  #### Related Guides  - [Invoke custom scripts](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_scripts_id_with_http_info(script_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str script_id: A script ID. Retrieves the specified script. (required)
        :return: Script
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        if not self._is_cloud_instance():
            from influxdb_client.client.warnings import CloudOnlyWarning
            CloudOnlyWarning.print_warning('InvokableScriptsService',
                                           'https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/')  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_scripts_id_prepare(script_id, **kwargs)  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/scripts/{scriptID}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='Script',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def get_scripts_id_async(self, script_id, **kwargs):  # noqa: E501,D401,D403
        """Retrieve a script.

        Retrieves a [script](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/).  #### Related Guides  - [Invoke custom scripts](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/)
        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param str script_id: A script ID. Retrieves the specified script. (required)
        :return: Script
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        if not await self._is_cloud_instance_async():
            from influxdb_client.client.warnings import CloudOnlyWarning
            CloudOnlyWarning.print_warning('InvokableScriptsService',
                                           'https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/')  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_scripts_id_prepare(script_id, **kwargs)  # noqa: E501

        return await self.api_client.call_api(
            '/api/v2/scripts/{scriptID}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='Script',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _get_scripts_id_prepare(self, script_id, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['script_id']  # noqa: E501
        self._check_operation_params('get_scripts_id', all_params, local_var_params)
        # verify the required parameter 'script_id' is set
        if ('script_id' not in local_var_params or
                local_var_params['script_id'] is None):
            raise ValueError("Missing the required parameter `script_id` when calling `get_scripts_id`")  # noqa: E501

        path_params = {}
        if 'script_id' in local_var_params:
            path_params['scriptID'] = local_var_params['script_id']  # noqa: E501

        query_params = []

        header_params = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params

    def get_scripts_id_params(self, script_id, **kwargs):  # noqa: E501,D401,D403
        """Find script parameters..

        Analyzes a script and determines required parameters. Find all `params` keys referenced in a script and return a list of keys. If it is possible to determine the type of the value from the context then the type is also returned -- for example:  The following sample script contains a _`mybucket`_ parameter :  ```json "script": "from(bucket: params.mybucket)             |> range(start: -7d)             |> limit(n:1)" ```  Requesting the parameters using `GET /api/v2/scripts/SCRIPT_ID/params` returns the following:  ```json {   "params": {     "mybucket": "string"   } } ```  The type name returned for a parameter will be one of:   - `any`  - `bool`  - `duration`  - `float`  - `int`  - `string`  - `time`  - `uint`  The type name `any` is used when the type of a parameter cannot be determined from the context, or the type is determined to be a structured type such as an array or record.  #### Related guides  - [Invoke custom scripts](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_scripts_id_params(script_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str script_id: A script ID. The script to analyze for params. (required)
        :return: Params
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_scripts_id_params_with_http_info(script_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_scripts_id_params_with_http_info(script_id, **kwargs)  # noqa: E501
            return data

    def get_scripts_id_params_with_http_info(self, script_id, **kwargs):  # noqa: E501,D401,D403
        """Find script parameters..

        Analyzes a script and determines required parameters. Find all `params` keys referenced in a script and return a list of keys. If it is possible to determine the type of the value from the context then the type is also returned -- for example:  The following sample script contains a _`mybucket`_ parameter :  ```json "script": "from(bucket: params.mybucket)             |> range(start: -7d)             |> limit(n:1)" ```  Requesting the parameters using `GET /api/v2/scripts/SCRIPT_ID/params` returns the following:  ```json {   "params": {     "mybucket": "string"   } } ```  The type name returned for a parameter will be one of:   - `any`  - `bool`  - `duration`  - `float`  - `int`  - `string`  - `time`  - `uint`  The type name `any` is used when the type of a parameter cannot be determined from the context, or the type is determined to be a structured type such as an array or record.  #### Related guides  - [Invoke custom scripts](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_scripts_id_params_with_http_info(script_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str script_id: A script ID. The script to analyze for params. (required)
        :return: Params
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        if not self._is_cloud_instance():
            from influxdb_client.client.warnings import CloudOnlyWarning
            CloudOnlyWarning.print_warning('InvokableScriptsService',
                                           'https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/')  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_scripts_id_params_prepare(script_id, **kwargs)  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/scripts/{scriptID}/params', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='Params',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def get_scripts_id_params_async(self, script_id, **kwargs):  # noqa: E501,D401,D403
        """Find script parameters..

        Analyzes a script and determines required parameters. Find all `params` keys referenced in a script and return a list of keys. If it is possible to determine the type of the value from the context then the type is also returned -- for example:  The following sample script contains a _`mybucket`_ parameter :  ```json "script": "from(bucket: params.mybucket)             |> range(start: -7d)             |> limit(n:1)" ```  Requesting the parameters using `GET /api/v2/scripts/SCRIPT_ID/params` returns the following:  ```json {   "params": {     "mybucket": "string"   } } ```  The type name returned for a parameter will be one of:   - `any`  - `bool`  - `duration`  - `float`  - `int`  - `string`  - `time`  - `uint`  The type name `any` is used when the type of a parameter cannot be determined from the context, or the type is determined to be a structured type such as an array or record.  #### Related guides  - [Invoke custom scripts](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/)
        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param str script_id: A script ID. The script to analyze for params. (required)
        :return: Params
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        if not await self._is_cloud_instance_async():
            from influxdb_client.client.warnings import CloudOnlyWarning
            CloudOnlyWarning.print_warning('InvokableScriptsService',
                                           'https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/')  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_scripts_id_params_prepare(script_id, **kwargs)  # noqa: E501

        return await self.api_client.call_api(
            '/api/v2/scripts/{scriptID}/params', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='Params',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _get_scripts_id_params_prepare(self, script_id, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['script_id']  # noqa: E501
        self._check_operation_params('get_scripts_id_params', all_params, local_var_params)
        # verify the required parameter 'script_id' is set
        if ('script_id' not in local_var_params or
                local_var_params['script_id'] is None):
            raise ValueError("Missing the required parameter `script_id` when calling `get_scripts_id_params`")  # noqa: E501

        path_params = {}
        if 'script_id' in local_var_params:
            path_params['scriptID'] = local_var_params['script_id']  # noqa: E501

        query_params = []

        header_params = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params

    def patch_scripts_id(self, script_id, script_update_request, **kwargs):  # noqa: E501,D401,D403
        """Update a script.

        Updates an invokable script.  Use this endpoint to modify values for script properties (`description` and `script`).  To update a script, pass an object that contains the updated key-value pairs.  #### Limitations  - If you send an empty request body, the script will neither update nor store an empty script, but InfluxDB will respond with an HTTP `200` status code.  #### Related Guides  - [Invoke custom scripts](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.patch_scripts_id(script_id, script_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str script_id: A script ID. Updates the specified script. (required)
        :param ScriptUpdateRequest script_update_request: An object that contains the updated script properties to apply.  (required)
        :return: Script
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.patch_scripts_id_with_http_info(script_id, script_update_request, **kwargs)  # noqa: E501
        else:
            (data) = self.patch_scripts_id_with_http_info(script_id, script_update_request, **kwargs)  # noqa: E501
            return data

    def patch_scripts_id_with_http_info(self, script_id, script_update_request, **kwargs):  # noqa: E501,D401,D403
        """Update a script.

        Updates an invokable script.  Use this endpoint to modify values for script properties (`description` and `script`).  To update a script, pass an object that contains the updated key-value pairs.  #### Limitations  - If you send an empty request body, the script will neither update nor store an empty script, but InfluxDB will respond with an HTTP `200` status code.  #### Related Guides  - [Invoke custom scripts](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.patch_scripts_id_with_http_info(script_id, script_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str script_id: A script ID. Updates the specified script. (required)
        :param ScriptUpdateRequest script_update_request: An object that contains the updated script properties to apply.  (required)
        :return: Script
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        if not self._is_cloud_instance():
            from influxdb_client.client.warnings import CloudOnlyWarning
            CloudOnlyWarning.print_warning('InvokableScriptsService',
                                           'https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/')  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._patch_scripts_id_prepare(script_id, script_update_request, **kwargs)  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/scripts/{scriptID}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='Script',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def patch_scripts_id_async(self, script_id, script_update_request, **kwargs):  # noqa: E501,D401,D403
        """Update a script.

        Updates an invokable script.  Use this endpoint to modify values for script properties (`description` and `script`).  To update a script, pass an object that contains the updated key-value pairs.  #### Limitations  - If you send an empty request body, the script will neither update nor store an empty script, but InfluxDB will respond with an HTTP `200` status code.  #### Related Guides  - [Invoke custom scripts](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/)
        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param str script_id: A script ID. Updates the specified script. (required)
        :param ScriptUpdateRequest script_update_request: An object that contains the updated script properties to apply.  (required)
        :return: Script
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        if not await self._is_cloud_instance_async():
            from influxdb_client.client.warnings import CloudOnlyWarning
            CloudOnlyWarning.print_warning('InvokableScriptsService',
                                           'https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/')  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._patch_scripts_id_prepare(script_id, script_update_request, **kwargs)  # noqa: E501

        return await self.api_client.call_api(
            '/api/v2/scripts/{scriptID}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='Script',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _patch_scripts_id_prepare(self, script_id, script_update_request, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['script_id', 'script_update_request']  # noqa: E501
        self._check_operation_params('patch_scripts_id', all_params, local_var_params)
        # verify the required parameter 'script_id' is set
        if ('script_id' not in local_var_params or
                local_var_params['script_id'] is None):
            raise ValueError("Missing the required parameter `script_id` when calling `patch_scripts_id`")  # noqa: E501
        # verify the required parameter 'script_update_request' is set
        if ('script_update_request' not in local_var_params or
                local_var_params['script_update_request'] is None):
            raise ValueError("Missing the required parameter `script_update_request` when calling `patch_scripts_id`")  # noqa: E501

        path_params = {}
        if 'script_id' in local_var_params:
            path_params['scriptID'] = local_var_params['script_id']  # noqa: E501

        query_params = []

        header_params = {}

        body_params = None
        if 'script_update_request' in local_var_params:
            body_params = local_var_params['script_update_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params

    def post_scripts(self, script_create_request, **kwargs):  # noqa: E501,D401,D403
        """Create a script.

        Creates an [invokable script](https://docs.influxdata.com/resources/videos/api-invokable-scripts/) and returns the script.  #### Related guides  - [Invokable scripts](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/) - [Creating custom InfluxDB endpoints](https://docs.influxdata.com/resources/videos/api-invokable-scripts/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_scripts(script_create_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ScriptCreateRequest script_create_request: The script to create. (required)
        :return: Script
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_scripts_with_http_info(script_create_request, **kwargs)  # noqa: E501
        else:
            (data) = self.post_scripts_with_http_info(script_create_request, **kwargs)  # noqa: E501
            return data

    def post_scripts_with_http_info(self, script_create_request, **kwargs):  # noqa: E501,D401,D403
        """Create a script.

        Creates an [invokable script](https://docs.influxdata.com/resources/videos/api-invokable-scripts/) and returns the script.  #### Related guides  - [Invokable scripts](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/) - [Creating custom InfluxDB endpoints](https://docs.influxdata.com/resources/videos/api-invokable-scripts/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_scripts_with_http_info(script_create_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ScriptCreateRequest script_create_request: The script to create. (required)
        :return: Script
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        if not self._is_cloud_instance():
            from influxdb_client.client.warnings import CloudOnlyWarning
            CloudOnlyWarning.print_warning('InvokableScriptsService',
                                           'https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/')  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._post_scripts_prepare(script_create_request, **kwargs)  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/scripts', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='Script',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def post_scripts_async(self, script_create_request, **kwargs):  # noqa: E501,D401,D403
        """Create a script.

        Creates an [invokable script](https://docs.influxdata.com/resources/videos/api-invokable-scripts/) and returns the script.  #### Related guides  - [Invokable scripts](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/) - [Creating custom InfluxDB endpoints](https://docs.influxdata.com/resources/videos/api-invokable-scripts/)
        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param ScriptCreateRequest script_create_request: The script to create. (required)
        :return: Script
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        if not await self._is_cloud_instance_async():
            from influxdb_client.client.warnings import CloudOnlyWarning
            CloudOnlyWarning.print_warning('InvokableScriptsService',
                                           'https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/')  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._post_scripts_prepare(script_create_request, **kwargs)  # noqa: E501

        return await self.api_client.call_api(
            '/api/v2/scripts', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='Script',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _post_scripts_prepare(self, script_create_request, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['script_create_request']  # noqa: E501
        self._check_operation_params('post_scripts', all_params, local_var_params)
        # verify the required parameter 'script_create_request' is set
        if ('script_create_request' not in local_var_params or
                local_var_params['script_create_request'] is None):
            raise ValueError("Missing the required parameter `script_create_request` when calling `post_scripts`")  # noqa: E501

        path_params = {}

        query_params = []

        header_params = {}

        body_params = None
        if 'script_create_request' in local_var_params:
            body_params = local_var_params['script_create_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params

    def post_scripts_id_invoke(self, script_id, **kwargs):  # noqa: E501,D401,D403
        """Invoke a script.

        Runs a script and returns the result. When the script runs, InfluxDB replaces `params` keys referenced in the script with `params` key-values passed in the request body--for example:  The following sample script contains a _`mybucket`_ parameter :  ```json "script": "from(bucket: params.mybucket)             |> range(start: -7d)             |> limit(n:1)" ```  The following example `POST /api/v2/scripts/SCRIPT_ID/invoke` request body passes a value for the _`mybucket`_ parameter:  ```json {   "params": {     "mybucket": "air_sensor"   } } ```  #### Related guides  - [Invoke custom scripts](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_scripts_id_invoke(script_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str script_id: A script ID. Runs the specified script. (required)
        :param ScriptInvocationParams script_invocation_params:
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_scripts_id_invoke_with_http_info(script_id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_scripts_id_invoke_with_http_info(script_id, **kwargs)  # noqa: E501
            return data

    def post_scripts_id_invoke_with_http_info(self, script_id, **kwargs):  # noqa: E501,D401,D403
        """Invoke a script.

        Runs a script and returns the result. When the script runs, InfluxDB replaces `params` keys referenced in the script with `params` key-values passed in the request body--for example:  The following sample script contains a _`mybucket`_ parameter :  ```json "script": "from(bucket: params.mybucket)             |> range(start: -7d)             |> limit(n:1)" ```  The following example `POST /api/v2/scripts/SCRIPT_ID/invoke` request body passes a value for the _`mybucket`_ parameter:  ```json {   "params": {     "mybucket": "air_sensor"   } } ```  #### Related guides  - [Invoke custom scripts](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_scripts_id_invoke_with_http_info(script_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str script_id: A script ID. Runs the specified script. (required)
        :param ScriptInvocationParams script_invocation_params:
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        if not self._is_cloud_instance():
            from influxdb_client.client.warnings import CloudOnlyWarning
            CloudOnlyWarning.print_warning('InvokableScriptsService',
                                           'https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/')  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._post_scripts_id_invoke_prepare(script_id, **kwargs)  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/scripts/{scriptID}/invoke', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='file',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def post_scripts_id_invoke_async(self, script_id, **kwargs):  # noqa: E501,D401,D403
        """Invoke a script.

        Runs a script and returns the result. When the script runs, InfluxDB replaces `params` keys referenced in the script with `params` key-values passed in the request body--for example:  The following sample script contains a _`mybucket`_ parameter :  ```json "script": "from(bucket: params.mybucket)             |> range(start: -7d)             |> limit(n:1)" ```  The following example `POST /api/v2/scripts/SCRIPT_ID/invoke` request body passes a value for the _`mybucket`_ parameter:  ```json {   "params": {     "mybucket": "air_sensor"   } } ```  #### Related guides  - [Invoke custom scripts](https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/)
        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param str script_id: A script ID. Runs the specified script. (required)
        :param ScriptInvocationParams script_invocation_params:
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        if not await self._is_cloud_instance_async():
            from influxdb_client.client.warnings import CloudOnlyWarning
            CloudOnlyWarning.print_warning('InvokableScriptsService',
                                           'https://docs.influxdata.com/influxdb/cloud/api-guide/api-invokable-scripts/')  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._post_scripts_id_invoke_prepare(script_id, **kwargs)  # noqa: E501

        return await self.api_client.call_api(
            '/api/v2/scripts/{scriptID}/invoke', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='file',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _post_scripts_id_invoke_prepare(self, script_id, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['script_id', 'script_invocation_params']  # noqa: E501
        self._check_operation_params('post_scripts_id_invoke', all_params, local_var_params)
        # verify the required parameter 'script_id' is set
        if ('script_id' not in local_var_params or
                local_var_params['script_id'] is None):
            raise ValueError("Missing the required parameter `script_id` when calling `post_scripts_id_invoke`")  # noqa: E501

        path_params = {}
        if 'script_id' in local_var_params:
            path_params['scriptID'] = local_var_params['script_id']  # noqa: E501

        query_params = []

        header_params = {}

        body_params = None
        if 'script_invocation_params' in local_var_params:
            body_params = local_var_params['script_invocation_params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/csv', 'application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params



# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

from influxdb_client.service._base_service import _BaseService


class PingService(_BaseService):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):  # noqa: E501,D401,D403
        """PingService - a operation defined in OpenAPI."""
        super().__init__(api_client)

    def get_ping(self, **kwargs):  # noqa: E501,D401,D403
        """Get the status of the instance.

        Retrieves the status and InfluxDB version of the instance.  Use this endpoint to monitor uptime for the InfluxDB instance. The response returns a HTTP `204` status code to inform you the instance is available.  #### InfluxDB Cloud  - Isn't versioned and doesn't return `X-Influxdb-Version` in the headers.  #### Related guides  - [Influx ping](https://docs.influxdata.com/influxdb/latest/reference/cli/influx/ping/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ping(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_ping_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_ping_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_ping_with_http_info(self, **kwargs):  # noqa: E501,D401,D403
        """Get the status of the instance.

        Retrieves the status and InfluxDB version of the instance.  Use this endpoint to monitor uptime for the InfluxDB instance. The response returns a HTTP `204` status code to inform you the instance is available.  #### InfluxDB Cloud  - Isn't versioned and doesn't return `X-Influxdb-Version` in the headers.  #### Related guides  - [Influx ping](https://docs.influxdata.com/influxdb/latest/reference/cli/influx/ping/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ping_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_ping_prepare(**kwargs)  # noqa: E501

        return self.api_client.call_api(
            '/ping', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type=None,  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def get_ping_async(self, **kwargs):  # noqa: E501,D401,D403
        """Get the status of the instance.

        Retrieves the status and InfluxDB version of the instance.  Use this endpoint to monitor uptime for the InfluxDB instance. The response returns a HTTP `204` status code to inform you the instance is available.  #### InfluxDB Cloud  - Isn't versioned and doesn't return `X-Influxdb-Version` in the headers.  #### Related guides  - [Influx ping](https://docs.influxdata.com/influxdb/latest/reference/cli/influx/ping/)
        This method makes an asynchronous HTTP request.

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_ping_prepare(**kwargs)  # noqa: E501

        return await self.api_client.call_api(
            '/ping', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type=None,  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _get_ping_prepare(self, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = []  # noqa: E501
        self._check_operation_params('get_ping', all_params, local_var_params)

        path_params = {}

        query_params = []

        header_params = {}

        body_params = None
        return local_var_params, path_params, query_params, header_params, body_params

    def head_ping(self, **kwargs):  # noqa: E501,D401,D403
        """Get the status of the instance.

        Returns the status and InfluxDB version of the instance.  Use this endpoint to monitor uptime for the InfluxDB instance. The response returns a HTTP `204` status code to inform you the instance is available.  #### InfluxDB Cloud  - Isn't versioned and doesn't return `X-Influxdb-Version` in the headers.  #### Related guides  - [Influx ping](https://docs.influxdata.com/influxdb/latest/reference/cli/influx/ping/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_ping(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.head_ping_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.head_ping_with_http_info(**kwargs)  # noqa: E501
            return data

    def head_ping_with_http_info(self, **kwargs):  # noqa: E501,D401,D403
        """Get the status of the instance.

        Returns the status and InfluxDB version of the instance.  Use this endpoint to monitor uptime for the InfluxDB instance. The response returns a HTTP `204` status code to inform you the instance is available.  #### InfluxDB Cloud  - Isn't versioned and doesn't return `X-Influxdb-Version` in the headers.  #### Related guides  - [Influx ping](https://docs.influxdata.com/influxdb/latest/reference/cli/influx/ping/)
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.head_ping_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._head_ping_prepare(**kwargs)  # noqa: E501

        return self.api_client.call_api(
            '/ping', 'HEAD',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type=None,  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def head_ping_async(self, **kwargs):  # noqa: E501,D401,D403
        """Get the status of the instance.

        Returns the status and InfluxDB version of the instance.  Use this endpoint to monitor uptime for the InfluxDB instance. The response returns a HTTP `204` status code to inform you the instance is available.  #### InfluxDB Cloud  - Isn't versioned and doesn't return `X-Influxdb-Version` in the headers.  #### Related guides  - [Influx ping](https://docs.influxdata.com/influxdb/latest/reference/cli/influx/ping/)
        This method makes an asynchronous HTTP request.

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._head_ping_prepare(**kwargs)  # noqa: E501

        return await self.api_client.call_api(
            '/ping', 'HEAD',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type=None,  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _head_ping_prepare(self, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = []  # noqa: E501
        self._check_operation_params('head_ping', all_params, local_var_params)

        path_params = {}

        query_params = []

        header_params = {}

        body_params = None
        return local_var_params, path_params, query_params, header_params, body_params



# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401


class Run(object):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'task_id': 'str',
        'status': 'str',
        'scheduled_for': 'datetime',
        'log': 'list[LogEvent]',
        'flux': 'str',
        'started_at': 'datetime',
        'finished_at': 'datetime',
        'requested_at': 'datetime',
        'links': 'RunLinks'
    }

    attribute_map = {
        'id': 'id',
        'task_id': 'taskID',
        'status': 'status',
        'scheduled_for': 'scheduledFor',
        'log': 'log',
        'flux': 'flux',
        'started_at': 'startedAt',
        'finished_at': 'finishedAt',
        'requested_at': 'requestedAt',
        'links': 'links'
    }

    def __init__(self, id=None, task_id=None, status=None, scheduled_for=None, log=None, flux=None, started_at=None, finished_at=None, requested_at=None, links=None):  # noqa: E501,D401,D403
        """Run - a model defined in OpenAPI."""  # noqa: E501
        self._id = None
        self._task_id = None
        self._status = None
        self._scheduled_for = None
        self._log = None
        self._flux = None
        self._started_at = None
        self._finished_at = None
        self._requested_at = None
        self._links = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if task_id is not None:
            self.task_id = task_id
        if status is not None:
            self.status = status
        if scheduled_for is not None:
            self.scheduled_for = scheduled_for
        if log is not None:
            self.log = log
        if flux is not None:
            self.flux = flux
        if started_at is not None:
            self.started_at = started_at
        if finished_at is not None:
            self.finished_at = finished_at
        if requested_at is not None:
            self.requested_at = requested_at
        if links is not None:
            self.links = links

    @property
    def id(self):
        """Get the id of this Run.

        :return: The id of this Run.
        :rtype: str
        """  # noqa: E501
        return self._id

    @id.setter
    def id(self, id):
        """Set the id of this Run.

        :param id: The id of this Run.
        :type: str
        """  # noqa: E501
        self._id = id

    @property
    def task_id(self):
        """Get the task_id of this Run.

        :return: The task_id of this Run.
        :rtype: str
        """  # noqa: E501
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        """Set the task_id of this Run.

        :param task_id: The task_id of this Run.
        :type: str
        """  # noqa: E501
        self._task_id = task_id

    @property
    def status(self):
        """Get the status of this Run.

        :return: The status of this Run.
        :rtype: str
        """  # noqa: E501
        return self._status

    @status.setter
    def status(self, status):
        """Set the status of this Run.

        :param status: The status of this Run.
        :type: str
        """  # noqa: E501
        self._status = status

    @property
    def scheduled_for(self):
        """Get the scheduled_for of this Run.

        The time [RFC3339 date/time format](https://docs.influxdata.com/influxdb/latest/reference/glossary/#rfc3339-timestamp) used for the run's `now` option.

        :return: The scheduled_for of this Run.
        :rtype: datetime
        """  # noqa: E501
        return self._scheduled_for

    @scheduled_for.setter
    def scheduled_for(self, scheduled_for):
        """Set the scheduled_for of this Run.

        The time [RFC3339 date/time format](https://docs.influxdata.com/influxdb/latest/reference/glossary/#rfc3339-timestamp) used for the run's `now` option.

        :param scheduled_for: The scheduled_for of this Run.
        :type: datetime
        """  # noqa: E501
        self._scheduled_for = scheduled_for

    @property
    def log(self):
        """Get the log of this Run.

        An array of logs associated with the run.

        :return: The log of this Run.
        :rtype: list[LogEvent]
        """  # noqa: E501
        return self._log

    @log.setter
    def log(self, log):
        """Set the log of this Run.

        An array of logs associated with the run.

        :param log: The log of this Run.
        :type: list[LogEvent]
        """  # noqa: E501
        self._log = log

    @property
    def flux(self):
        """Get the flux of this Run.

        Flux used for the task

        :return: The flux of this Run.
        :rtype: str
        """  # noqa: E501
        return self._flux

    @flux.setter
    def flux(self, flux):
        """Set the flux of this Run.

        Flux used for the task

        :param flux: The flux of this Run.
        :type: str
        """  # noqa: E501
        self._flux = flux

    @property
    def started_at(self):
        """Get the started_at of this Run.

        The time ([RFC3339Nano date/time format](https://go.dev/src/time/format.go)) the run started executing.

        :return: The started_at of this Run.
        :rtype: datetime
        """  # noqa: E501
        return self._started_at

    @started_at.setter
    def started_at(self, started_at):
        """Set the started_at of this Run.

        The time ([RFC3339Nano date/time format](https://go.dev/src/time/format.go)) the run started executing.

        :param started_at: The started_at of this Run.
        :type: datetime
        """  # noqa: E501
        self._started_at = started_at

    @property
    def finished_at(self):
        """Get the finished_at of this Run.

        The time ([RFC3339Nano date/time format](https://go.dev/src/time/format.go)) the run finished executing.

        :return: The finished_at of this Run.
        :rtype: datetime
        """  # noqa: E501
        return self._finished_at

    @finished_at.setter
    def finished_at(self, finished_at):
        """Set the finished_at of this Run.

        The time ([RFC3339Nano date/time format](https://go.dev/src/time/format.go)) the run finished executing.

        :param finished_at: The finished_at of this Run.
        :type: datetime
        """  # noqa: E501
        self._finished_at = finished_at

    @property
    def requested_at(self):
        """Get the requested_at of this Run.

        The time ([RFC3339Nano date/time format](https://docs.influxdata.com/influxdb/latest/reference/glossary/#rfc3339nano-timestamp)) the run was manually requested.

        :return: The requested_at of this Run.
        :rtype: datetime
        """  # noqa: E501
        return self._requested_at

    @requested_at.setter
    def requested_at(self, requested_at):
        """Set the requested_at of this Run.

        The time ([RFC3339Nano date/time format](https://docs.influxdata.com/influxdb/latest/reference/glossary/#rfc3339nano-timestamp)) the run was manually requested.

        :param requested_at: The requested_at of this Run.
        :type: datetime
        """  # noqa: E501
        self._requested_at = requested_at

    @property
    def links(self):
        """Get the links of this Run.

        :return: The links of this Run.
        :rtype: RunLinks
        """  # noqa: E501
        return self._links

    @links.setter
    def links(self, links):
        """Set the links of this Run.

        :param links: The links of this Run.
        :type: RunLinks
        """  # noqa: E501
        self._links = links

    def to_dict(self):
        """Return the model properties as a dict."""
        result = {}

        for attr, _ in self.openapi_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Return the string representation of the model."""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`."""
        return self.to_str()

    def __eq__(self, other):
        """Return true if both objects are equal."""
        if not isinstance(other, Run):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Return true if both objects are not equal."""
        return not self == other



# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

from influxdb_client.service._base_service import _BaseService


class ResourcesService(_BaseService):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):  # noqa: E501,D401,D403
        """ResourcesService - a operation defined in OpenAPI."""
        super().__init__(api_client)

    def get_resources(self, **kwargs):  # noqa: E501,D401,D403
        """List all known resources.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_resources(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str zap_trace_span: OpenTracing span context
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_resources_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_resources_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_resources_with_http_info(self, **kwargs):  # noqa: E501,D401,D403
        """List all known resources.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_resources_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str zap_trace_span: OpenTracing span context
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_resources_prepare(**kwargs)  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/resources', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='list[str]',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    async def get_resources_async(self, **kwargs):  # noqa: E501,D401,D403
        """List all known resources.

        This method makes an asynchronous HTTP request.

        :param async_req bool
        :param str zap_trace_span: OpenTracing span context
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """  # noqa: E501
        local_var_params, path_params, query_params, header_params, body_params = \
            self._get_resources_prepare(**kwargs)  # noqa: E501

        return await self.api_client.call_api(
            '/api/v2/resources', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=[],
            files={},
            response_type='list[str]',  # noqa: E501
            auth_settings=[],
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats={},
            urlopen_kw=kwargs.get('urlopen_kw', None))

    def _get_resources_prepare(self, **kwargs):  # noqa: E501,D401,D403
        local_var_params = locals()

        all_params = ['zap_trace_span']  # noqa: E501
        self._check_operation_params('get_resources', all_params, local_var_params)

        path_params = {}

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        return local_var_params, path_params, query_params, header_params, body_params



# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

from influxdb_client.domain.scraper_target_request import ScraperTargetRequest


class ScraperTargetResponse(ScraperTargetRequest):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'org': 'str',
        'bucket': 'str',
        'links': 'object',
        'name': 'str',
        'type': 'str',
        'url': 'str',
        'org_id': 'str',
        'bucket_id': 'str',
        'allow_insecure': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'org': 'org',
        'bucket': 'bucket',
        'links': 'links',
        'name': 'name',
        'type': 'type',
        'url': 'url',
        'org_id': 'orgID',
        'bucket_id': 'bucketID',
        'allow_insecure': 'allowInsecure'
    }

    def __init__(self, id=None, org=None, bucket=None, links=None, name=None, type=None, url=None, org_id=None, bucket_id=None, allow_insecure=False):  # noqa: E501,D401,D403
        """ScraperTargetResponse - a model defined in OpenAPI."""  # noqa: E501
        ScraperTargetRequest.__init__(self, name=name, type=type, url=url, org_id=org_id, bucket_id=bucket_id, allow_insecure=allow_insecure)  # noqa: E501

        self._id = None
        self._org = None
        self._bucket = None
        self._links = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if org is not None:
            self.org = org
        if bucket is not None:
            self.bucket = bucket
        if links is not None:
            self.links = links

    @property
    def id(self):
        """Get the id of this ScraperTargetResponse.

        :return: The id of this ScraperTargetResponse.
        :rtype: str
        """  # noqa: E501
        return self._id

    @id.setter
    def id(self, id):
        """Set the id of this ScraperTargetResponse.

        :param id: The id of this ScraperTargetResponse.
        :type: str
        """  # noqa: E501
        self._id = id

    @property
    def org(self):
        """Get the org of this ScraperTargetResponse.

        The name of the organization.

        :return: The org of this ScraperTargetResponse.
        :rtype: str
        """  # noqa: E501
        return self._org

    @org.setter
    def org(self, org):
        """Set the org of this ScraperTargetResponse.

        The name of the organization.

        :param org: The org of this ScraperTargetResponse.
        :type: str
        """  # noqa: E501
        self._org = org

    @property
    def bucket(self):
        """Get the bucket of this ScraperTargetResponse.

        The bucket name.

        :return: The bucket of this ScraperTargetResponse.
        :rtype: str
        """  # noqa: E501
        return self._bucket

    @bucket.setter
    def bucket(self, bucket):
        """Set the bucket of this ScraperTargetResponse.

        The bucket name.

        :param bucket: The bucket of this ScraperTargetResponse.
        :type: str
        """  # noqa: E501
        self._bucket = bucket

    @property
    def links(self):
        """Get the links of this ScraperTargetResponse.

        :return: The links of this ScraperTargetResponse.
        :rtype: object
        """  # noqa: E501
        return self._links

    @links.setter
    def links(self, links):
        """Set the links of this ScraperTargetResponse.

        :param links: The links of this ScraperTargetResponse.
        :type: object
        """  # noqa: E501
        self._links = links

    def to_dict(self):
        """Return the model properties as a dict."""
        result = {}

        for attr, _ in self.openapi_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Return the string representation of the model."""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`."""
        return self.to_str()

    def __eq__(self, other):
        """Return true if both objects are equal."""
        if not isinstance(other, ScraperTargetResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Return true if both objects are not equal."""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from influxdb_client.domain.ast_response import ASTResponse
from influxdb_client.domain.add_resource_member_request_body import AddResourceMemberRequestBody
from influxdb_client.domain.analyze_query_response import AnalyzeQueryResponse
from influxdb_client.domain.analyze_query_response_errors import AnalyzeQueryResponseErrors
from influxdb_client.domain.array_expression import ArrayExpression
from influxdb_client.domain.authorization import Authorization
from influxdb_client.domain.authorization_post_request import AuthorizationPostRequest
from influxdb_client.domain.authorization_update_request import AuthorizationUpdateRequest
from influxdb_client.domain.authorizations import Authorizations
from influxdb_client.domain.axes import Axes
from influxdb_client.domain.axis import Axis
from influxdb_client.domain.axis_scale import AxisScale
from influxdb_client.domain.bad_statement import BadStatement
from influxdb_client.domain.band_view_properties import BandViewProperties
from influxdb_client.domain.binary_expression import BinaryExpression
from influxdb_client.domain.block import Block
from influxdb_client.domain.boolean_literal import BooleanLiteral
from influxdb_client.domain.bucket import Bucket
from influxdb_client.domain.bucket_links import BucketLinks
from influxdb_client.domain.bucket_metadata_manifest import BucketMetadataManifest
from influxdb_client.domain.bucket_retention_rules import BucketRetentionRules
from influxdb_client.domain.bucket_shard_mapping import BucketShardMapping
from influxdb_client.domain.buckets import Buckets
from influxdb_client.domain.builder_aggregate_function_type import BuilderAggregateFunctionType
from influxdb_client.domain.builder_config import BuilderConfig
from influxdb_client.domain.builder_config_aggregate_window import BuilderConfigAggregateWindow
from influxdb_client.domain.builder_functions_type import BuilderFunctionsType
from influxdb_client.domain.builder_tags_type import BuilderTagsType
from influxdb_client.domain.builtin_statement import BuiltinStatement
from influxdb_client.domain.call_expression import CallExpression
from influxdb_client.domain.cell import Cell
from influxdb_client.domain.cell_links import CellLinks
from influxdb_client.domain.cell_update import CellUpdate
from influxdb_client.domain.cell_with_view_properties import CellWithViewProperties
from influxdb_client.domain.check import Check
from influxdb_client.domain.check_base import CheckBase
from influxdb_client.domain.check_base_links import CheckBaseLinks
from influxdb_client.domain.check_discriminator import CheckDiscriminator
from influxdb_client.domain.check_patch import CheckPatch
from influxdb_client.domain.check_status_level import CheckStatusLevel
from influxdb_client.domain.check_view_properties import CheckViewProperties
from influxdb_client.domain.checks import Checks
from influxdb_client.domain.column_data_type import ColumnDataType
from influxdb_client.domain.column_semantic_type import ColumnSemanticType
from influxdb_client.domain.conditional_expression import ConditionalExpression
from influxdb_client.domain.config import Config
from influxdb_client.domain.constant_variable_properties import ConstantVariableProperties
from influxdb_client.domain.create_cell import CreateCell
from influxdb_client.domain.create_dashboard_request import CreateDashboardRequest
from influxdb_client.domain.custom_check import CustomCheck
from influxdb_client.domain.dbrp import DBRP
from influxdb_client.domain.dbrp_create import DBRPCreate
from influxdb_client.domain.dbrp_get import DBRPGet
from influxdb_client.domain.dbrp_update import DBRPUpdate
from influxdb_client.domain.dbr_ps import DBRPs
from influxdb_client.domain.dashboard import Dashboard
from influxdb_client.domain.dashboard_color import DashboardColor
from influxdb_client.domain.dashboard_query import DashboardQuery
from influxdb_client.domain.dashboard_with_view_properties import DashboardWithViewProperties
from influxdb_client.domain.dashboards import Dashboards
from influxdb_client.domain.date_time_literal import DateTimeLiteral
from influxdb_client.domain.deadman_check import DeadmanCheck
from influxdb_client.domain.decimal_places import DecimalPlaces
from influxdb_client.domain.delete_predicate_request import DeletePredicateRequest
from influxdb_client.domain.dialect import Dialect
from influxdb_client.domain.dict_expression import DictExpression
from influxdb_client.domain.dict_item import DictItem
from influxdb_client.domain.duration import Duration
from influxdb_client.domain.duration_literal import DurationLiteral
from influxdb_client.domain.error import Error
from influxdb_client.domain.expression import Expression
from influxdb_client.domain.expression_statement import ExpressionStatement
from influxdb_client.domain.field import Field
from influxdb_client.domain.file import File
from influxdb_client.domain.float_literal import FloatLiteral
from influxdb_client.domain.flux_response import FluxResponse
from influxdb_client.domain.flux_suggestion import FluxSuggestion
from influxdb_client.domain.flux_suggestions import FluxSuggestions
from influxdb_client.domain.function_expression import FunctionExpression
from influxdb_client.domain.gauge_view_properties import GaugeViewProperties
from influxdb_client.domain.greater_threshold import GreaterThreshold
from influxdb_client.domain.http_notification_endpoint import HTTPNotificationEndpoint
from influxdb_client.domain.http_notification_rule import HTTPNotificationRule
from influxdb_client.domain.http_notification_rule_base import HTTPNotificationRuleBase
from influxdb_client.domain.health_check import HealthCheck
from influxdb_client.domain.heatmap_view_properties import HeatmapViewProperties
from influxdb_client.domain.histogram_view_properties import HistogramViewProperties
from influxdb_client.domain.identifier import Identifier
from influxdb_client.domain.import_declaration import ImportDeclaration
from influxdb_client.domain.index_expression import IndexExpression
from influxdb_client.domain.integer_literal import IntegerLiteral
from influxdb_client.domain.is_onboarding import IsOnboarding
from influxdb_client.domain.label import Label
from influxdb_client.domain.label_create_request import LabelCreateRequest
from influxdb_client.domain.label_mapping import LabelMapping
from influxdb_client.domain.label_response import LabelResponse
from influxdb_client.domain.label_update import LabelUpdate
from influxdb_client.domain.labels_response import LabelsResponse
from influxdb_client.domain.language_request import LanguageRequest
from influxdb_client.domain.legacy_authorization_post_request import LegacyAuthorizationPostRequest
from influxdb_client.domain.lesser_threshold import LesserThreshold
from influxdb_client.domain.line_plus_single_stat_properties import LinePlusSingleStatProperties
from influxdb_client.domain.line_protocol_error import LineProtocolError
from influxdb_client.domain.line_protocol_length_error import LineProtocolLengthError
from influxdb_client.domain.links import Links
from influxdb_client.domain.list_stacks_response import ListStacksResponse
from influxdb_client.domain.log_event import LogEvent
from influxdb_client.domain.logical_expression import LogicalExpression
from influxdb_client.domain.logs import Logs
from influxdb_client.domain.map_variable_properties import MapVariableProperties
from influxdb_client.domain.markdown_view_properties import MarkdownViewProperties
from influxdb_client.domain.measurement_schema import MeasurementSchema
from influxdb_client.domain.measurement_schema_column import MeasurementSchemaColumn
from influxdb_client.domain.measurement_schema_create_request import MeasurementSchemaCreateRequest
from influxdb_client.domain.measurement_schema_list import MeasurementSchemaList
from influxdb_client.domain.measurement_schema_update_request import MeasurementSchemaUpdateRequest
from influxdb_client.domain.member_assignment import MemberAssignment
from influxdb_client.domain.member_expression import MemberExpression
from influxdb_client.domain.metadata_backup import MetadataBackup
from influxdb_client.domain.model_property import ModelProperty
from influxdb_client.domain.mosaic_view_properties import MosaicViewProperties
from influxdb_client.domain.node import Node
from influxdb_client.domain.notification_endpoint import NotificationEndpoint
from influxdb_client.domain.notification_endpoint_base import NotificationEndpointBase
from influxdb_client.domain.notification_endpoint_base_links import NotificationEndpointBaseLinks
from influxdb_client.domain.notification_endpoint_discriminator import NotificationEndpointDiscriminator
from influxdb_client.domain.notification_endpoint_type import NotificationEndpointType
from influxdb_client.domain.notification_endpoint_update import NotificationEndpointUpdate
from influxdb_client.domain.notification_endpoints import NotificationEndpoints
from influxdb_client.domain.notification_rule import NotificationRule
from influxdb_client.domain.notification_rule_base import NotificationRuleBase
from influxdb_client.domain.notification_rule_base_links import NotificationRuleBaseLinks
from influxdb_client.domain.notification_rule_discriminator import NotificationRuleDiscriminator
from influxdb_client.domain.notification_rule_update import NotificationRuleUpdate
from influxdb_client.domain.notification_rules import NotificationRules
from influxdb_client.domain.object_expression import ObjectExpression
from influxdb_client.domain.onboarding_request import OnboardingRequest
from influxdb_client.domain.onboarding_response import OnboardingResponse
from influxdb_client.domain.option_statement import OptionStatement
from influxdb_client.domain.organization import Organization
from influxdb_client.domain.organization_links import OrganizationLinks
from influxdb_client.domain.organizations import Organizations
from influxdb_client.domain.package import Package
from influxdb_client.domain.package_clause import PackageClause
from influxdb_client.domain.pager_duty_notification_endpoint import PagerDutyNotificationEndpoint
from influxdb_client.domain.pager_duty_notification_rule import PagerDutyNotificationRule
from influxdb_client.domain.pager_duty_notification_rule_base import PagerDutyNotificationRuleBase
from influxdb_client.domain.paren_expression import ParenExpression
from influxdb_client.domain.password_reset_body import PasswordResetBody
from influxdb_client.domain.patch_bucket_request import PatchBucketRequest
from influxdb_client.domain.patch_dashboard_request import PatchDashboardRequest
from influxdb_client.domain.patch_organization_request import PatchOrganizationRequest
from influxdb_client.domain.patch_retention_rule import PatchRetentionRule
from influxdb_client.domain.patch_stack_request import PatchStackRequest
from influxdb_client.domain.patch_stack_request_additional_resources import PatchStackRequestAdditionalResources
from influxdb_client.domain.permission import Permission
from influxdb_client.domain.permission_resource import PermissionResource
from influxdb_client.domain.pipe_expression import PipeExpression
from influxdb_client.domain.pipe_literal import PipeLiteral
from influxdb_client.domain.post_bucket_request import PostBucketRequest
from influxdb_client.domain.post_check import PostCheck
from influxdb_client.domain.post_notification_endpoint import PostNotificationEndpoint
from influxdb_client.domain.post_notification_rule import PostNotificationRule
from influxdb_client.domain.post_organization_request import PostOrganizationRequest
from influxdb_client.domain.post_restore_kv_response import PostRestoreKVResponse
from influxdb_client.domain.post_stack_request import PostStackRequest
from influxdb_client.domain.property_key import PropertyKey
from influxdb_client.domain.query import Query
from influxdb_client.domain.query_edit_mode import QueryEditMode
from influxdb_client.domain.query_variable_properties import QueryVariableProperties
from influxdb_client.domain.query_variable_properties_values import QueryVariablePropertiesValues
from influxdb_client.domain.range_threshold import RangeThreshold
from influxdb_client.domain.ready import Ready
from influxdb_client.domain.regexp_literal import RegexpLiteral
from influxdb_client.domain.remote_connection import RemoteConnection
from influxdb_client.domain.remote_connection_creation_request import RemoteConnectionCreationRequest
from influxdb_client.domain.remote_connection_update_request import RemoteConnectionUpdateRequest
from influxdb_client.domain.remote_connections import RemoteConnections
from influxdb_client.domain.renamable_field import RenamableField
from influxdb_client.domain.replication import Replication
from influxdb_client.domain.replication_creation_request import ReplicationCreationRequest
from influxdb_client.domain.replication_update_request import ReplicationUpdateRequest
from influxdb_client.domain.replications import Replications
from influxdb_client.domain.resource_member import ResourceMember
from influxdb_client.domain.resource_members import ResourceMembers
from influxdb_client.domain.resource_members_links import ResourceMembersLinks
from influxdb_client.domain.resource_owner import ResourceOwner
from influxdb_client.domain.resource_owners import ResourceOwners
from influxdb_client.domain.restored_bucket_mappings import RestoredBucketMappings
from influxdb_client.domain.retention_policy_manifest import RetentionPolicyManifest
from influxdb_client.domain.return_statement import ReturnStatement
from influxdb_client.domain.routes import Routes
from influxdb_client.domain.routes_external import RoutesExternal
from influxdb_client.domain.routes_query import RoutesQuery
from influxdb_client.domain.routes_system import RoutesSystem
from influxdb_client.domain.rule_status_level import RuleStatusLevel
from influxdb_client.domain.run import Run
from influxdb_client.domain.run_links import RunLinks
from influxdb_client.domain.run_manually import RunManually
from influxdb_client.domain.runs import Runs
from influxdb_client.domain.smtp_notification_rule import SMTPNotificationRule
from influxdb_client.domain.smtp_notification_rule_base import SMTPNotificationRuleBase
from influxdb_client.domain.scatter_view_properties import ScatterViewProperties
from influxdb_client.domain.schema_type import SchemaType
from influxdb_client.domain.scraper_target_request import ScraperTargetRequest
from influxdb_client.domain.scraper_target_response import ScraperTargetResponse
from influxdb_client.domain.scraper_target_responses import ScraperTargetResponses
from influxdb_client.domain.script import Script
from influxdb_client.domain.script_create_request import ScriptCreateRequest
from influxdb_client.domain.script_invocation_params import ScriptInvocationParams
from influxdb_client.domain.script_language import ScriptLanguage
from influxdb_client.domain.script_update_request import ScriptUpdateRequest
from influxdb_client.domain.scripts import Scripts
from influxdb_client.domain.secret_keys import SecretKeys
from influxdb_client.domain.secret_keys_response import SecretKeysResponse
from influxdb_client.domain.shard_group_manifest import ShardGroupManifest
from influxdb_client.domain.shard_manifest import ShardManifest
from influxdb_client.domain.shard_owner import ShardOwner
from influxdb_client.domain.simple_table_view_properties import SimpleTableViewProperties
from influxdb_client.domain.single_stat_view_properties import SingleStatViewProperties
from influxdb_client.domain.slack_notification_endpoint import SlackNotificationEndpoint
from influxdb_client.domain.slack_notification_rule import SlackNotificationRule
from influxdb_client.domain.slack_notification_rule_base import SlackNotificationRuleBase
from influxdb_client.domain.source import Source
from influxdb_client.domain.source_links import SourceLinks
from influxdb_client.domain.sources import Sources
from influxdb_client.domain.stack import Stack
from influxdb_client.domain.stack_associations import StackAssociations
from influxdb_client.domain.stack_events import StackEvents
from influxdb_client.domain.stack_links import StackLinks
from influxdb_client.domain.stack_resources import StackResources
from influxdb_client.domain.statement import Statement
from influxdb_client.domain.static_legend import StaticLegend
from influxdb_client.domain.status_rule import StatusRule
from influxdb_client.domain.string_literal import StringLiteral
from influxdb_client.domain.subscription_manifest import SubscriptionManifest
from influxdb_client.domain.table_view_properties import TableViewProperties
from influxdb_client.domain.table_view_properties_table_options import TableViewPropertiesTableOptions
from influxdb_client.domain.tag_rule import TagRule
from influxdb_client.domain.task import Task
from influxdb_client.domain.task_create_request import TaskCreateRequest
from influxdb_client.domain.task_links import TaskLinks
from influxdb_client.domain.task_status_type import TaskStatusType
from influxdb_client.domain.task_update_request import TaskUpdateRequest
from influxdb_client.domain.tasks import Tasks
from influxdb_client.domain.telegraf import Telegraf
from influxdb_client.domain.telegraf_plugin import TelegrafPlugin
from influxdb_client.domain.telegraf_plugin_request import TelegrafPluginRequest
from influxdb_client.domain.telegraf_plugin_request_plugins import TelegrafPluginRequestPlugins
from influxdb_client.domain.telegraf_plugins import TelegrafPlugins
from influxdb_client.domain.telegraf_request import TelegrafRequest
from influxdb_client.domain.telegraf_request_metadata import TelegrafRequestMetadata
from influxdb_client.domain.telegrafs import Telegrafs
from influxdb_client.domain.telegram_notification_endpoint import TelegramNotificationEndpoint
from influxdb_client.domain.telegram_notification_rule import TelegramNotificationRule
from influxdb_client.domain.telegram_notification_rule_base import TelegramNotificationRuleBase
from influxdb_client.domain.template_apply import TemplateApply
from influxdb_client.domain.template_apply_remotes import TemplateApplyRemotes
from influxdb_client.domain.template_apply_template import TemplateApplyTemplate
from influxdb_client.domain.template_chart import TemplateChart
from influxdb_client.domain.template_export_by_id import TemplateExportByID
from influxdb_client.domain.template_export_by_id_org_ids import TemplateExportByIDOrgIDs
from influxdb_client.domain.template_export_by_id_resource_filters import TemplateExportByIDResourceFilters
from influxdb_client.domain.template_export_by_id_resources import TemplateExportByIDResources
from influxdb_client.domain.template_export_by_name import TemplateExportByName
from influxdb_client.domain.template_export_by_name_resources import TemplateExportByNameResources
from influxdb_client.domain.template_kind import TemplateKind
from influxdb_client.domain.template_summary import TemplateSummary
from influxdb_client.domain.template_summary_diff import TemplateSummaryDiff
from influxdb_client.domain.template_summary_diff_buckets import TemplateSummaryDiffBuckets
from influxdb_client.domain.template_summary_diff_buckets_new_old import TemplateSummaryDiffBucketsNewOld
from influxdb_client.domain.template_summary_diff_checks import TemplateSummaryDiffChecks
from influxdb_client.domain.template_summary_diff_dashboards import TemplateSummaryDiffDashboards
from influxdb_client.domain.template_summary_diff_dashboards_new_old import TemplateSummaryDiffDashboardsNewOld
from influxdb_client.domain.template_summary_diff_label_mappings import TemplateSummaryDiffLabelMappings
from influxdb_client.domain.template_summary_diff_labels import TemplateSummaryDiffLabels
from influxdb_client.domain.template_summary_diff_labels_new_old import TemplateSummaryDiffLabelsNewOld
from influxdb_client.domain.template_summary_diff_notification_endpoints import TemplateSummaryDiffNotificationEndpoints
from influxdb_client.domain.template_summary_diff_notification_rules import TemplateSummaryDiffNotificationRules
from influxdb_client.domain.template_summary_diff_notification_rules_new_old import TemplateSummaryDiffNotificationRulesNewOld
from influxdb_client.domain.template_summary_diff_tasks import TemplateSummaryDiffTasks
from influxdb_client.domain.template_summary_diff_tasks_new_old import TemplateSummaryDiffTasksNewOld
from influxdb_client.domain.template_summary_diff_telegraf_configs import TemplateSummaryDiffTelegrafConfigs
from influxdb_client.domain.template_summary_diff_variables import TemplateSummaryDiffVariables
from influxdb_client.domain.template_summary_diff_variables_new_old import TemplateSummaryDiffVariablesNewOld
from influxdb_client.domain.template_summary_errors import TemplateSummaryErrors
from influxdb_client.domain.template_summary_label import TemplateSummaryLabel
from influxdb_client.domain.template_summary_label_properties import TemplateSummaryLabelProperties
from influxdb_client.domain.template_summary_summary import TemplateSummarySummary
from influxdb_client.domain.template_summary_summary_buckets import TemplateSummarySummaryBuckets
from influxdb_client.domain.template_summary_summary_dashboards import TemplateSummarySummaryDashboards
from influxdb_client.domain.template_summary_summary_label_mappings import TemplateSummarySummaryLabelMappings
from influxdb_client.domain.template_summary_summary_notification_rules import TemplateSummarySummaryNotificationRules
from influxdb_client.domain.template_summary_summary_status_rules import TemplateSummarySummaryStatusRules
from influxdb_client.domain.template_summary_summary_tag_rules import TemplateSummarySummaryTagRules
from influxdb_client.domain.template_summary_summary_tasks import TemplateSummarySummaryTasks
from influxdb_client.domain.template_summary_summary_variables import TemplateSummarySummaryVariables
from influxdb_client.domain.test_statement import TestStatement
from influxdb_client.domain.threshold import Threshold
from influxdb_client.domain.threshold_base import ThresholdBase
from influxdb_client.domain.threshold_check import ThresholdCheck
from influxdb_client.domain.unary_expression import UnaryExpression
from influxdb_client.domain.unsigned_integer_literal import UnsignedIntegerLiteral
from influxdb_client.domain.user import User
from influxdb_client.domain.user_response import UserResponse
from influxdb_client.domain.user_response_links import UserResponseLinks
from influxdb_client.domain.users import Users
from influxdb_client.domain.variable import Variable
from influxdb_client.domain.variable_assignment import VariableAssignment
from influxdb_client.domain.variable_links import VariableLinks
from influxdb_client.domain.variable_properties import VariableProperties
from influxdb_client.domain.variables import Variables
from influxdb_client.domain.view import View
from influxdb_client.domain.view_links import ViewLinks
from influxdb_client.domain.view_properties import ViewProperties
from influxdb_client.domain.views import Views
from influxdb_client.domain.write_precision import WritePrecision
from influxdb_client.domain.xy_geom import XYGeom
from influxdb_client.domain.xy_view_properties import XYViewProperties



"""
Querying InfluxDB by FluxLang.

Flux is InfluxData’s functional data scripting language designed for querying, analyzing, and acting on data.
"""

from typing import List, Generator, Any, Callable

from influxdb_client import Dialect
from influxdb_client.client._base import _BaseQueryApi
from influxdb_client.client.flux_table import FluxRecord, TableList, CSVIterator


class QueryOptions(object):
    """Query options."""

    def __init__(self, profilers: List[str] = None, profiler_callback: Callable = None) -> None:
        """
        Initialize query options.

        :param profilers: list of enabled flux profilers
        :param profiler_callback: callback function return profilers (FluxRecord)
        """
        self.profilers = profilers
        self.profiler_callback = profiler_callback


class QueryApi(_BaseQueryApi):
    """Implementation for '/api/v2/query' endpoint."""

    def __init__(self, influxdb_client, query_options=QueryOptions()):
        """
        Initialize query client.

        :param influxdb_client: influxdb client
        """
        super().__init__(influxdb_client=influxdb_client, query_options=query_options)

    def query_csv(self, query: str, org=None, dialect: Dialect = _BaseQueryApi.default_dialect, params: dict = None) \
            -> CSVIterator:
        """
        Execute the Flux query and return results as a CSV iterator. Each iteration returns a row of the CSV file.

        :param query: a Flux query
        :param str, Organization org: specifies the organization for executing the query;
                                      Take the ``ID``, ``Name`` or ``Organization``.
                                      If not specified the default value from ``InfluxDBClient.org`` is used.
        :param dialect: csv dialect format
        :param params: bind parameters
        :return: :class:`~Iterator[List[str]]` wrapped into :class:`~influxdb_client.client.flux_table.CSVIterator`
        :rtype: CSVIterator

        Serialization the query results to flattened list of values via :func:`~influxdb_client.client.flux_table.CSVIterator.to_values`:

        .. code-block:: python

            from influxdb_client import InfluxDBClient

            with InfluxDBClient(url="http://localhost:8086", token="my-token", org="my-org") as client:

                # Query: using CSV iterator
                csv_iterator = client.query_api().query_csv('from(bucket:"my-bucket") |> range(start: -10m)')

                # Serialize to values
                output = csv_iterator.to_values()
                print(output)

        .. code-block:: python

            [
                ['#datatype', 'string', 'long', 'dateTime:RFC3339', 'dateTime:RFC3339', 'dateTime:RFC3339', 'double', 'string', 'string', 'string']
                ['#group', 'false', 'false', 'true', 'true', 'false', 'false', 'true', 'true', 'true']
                ['#default', '_result', '', '', '', '', '', '', '', '']
                ['', 'result', 'table', '_start', '_stop', '_time', '_value', '_field', '_measurement', 'location']
                ['', '', '0', '2022-06-16', '2022-06-16', '2022-06-16', '24.3', 'temperature', 'my_measurement', 'New York']
                ['', '', '1', '2022-06-16', '2022-06-16', '2022-06-16', '25.3', 'temperature', 'my_measurement', 'Prague']
                ...
            ]

        If you would like to turn off `Annotated CSV header's <https://docs.influxdata.com/influxdb/latest/reference/syntax/annotated-csv/>`_ you can use following code:

        .. code-block:: python

            from influxdb_client import InfluxDBClient, Dialect

            with InfluxDBClient(url="http://localhost:8086", token="my-token", org="my-org") as client:

                # Query: using CSV iterator
                csv_iterator = client.query_api().query_csv('from(bucket:"my-bucket") |> range(start: -10m)',
                                                            dialect=Dialect(header=False, annotations=[]))

                for csv_line in csv_iterator:
                    print(csv_line)

        .. code-block:: python

            [
                ['', '_result', '0', '2022-06-16', '2022-06-16', '2022-06-16', '24.3', 'temperature', 'my_measurement', 'New York']
                ['', '_result', '1', '2022-06-16', '2022-06-16', '2022-06-16', '25.3', 'temperature', 'my_measurement', 'Prague']
                ...
            ]
        """  # noqa: E501
        org = self._org_param(org)
        response = self._query_api.post_query(org=org, query=self._create_query(query, dialect, params),
                                              async_req=False, _preload_content=False)

        return self._to_csv(response)

    def query_raw(self, query: str, org=None, dialect=_BaseQueryApi.default_dialect, params: dict = None):
        """
        Execute synchronous Flux query and return result as raw unprocessed result as a str.

        :param query: a Flux query
        :param str, Organization org: specifies the organization for executing the query;
                                      Take the ``ID``, ``Name`` or ``Organization``.
                                      If not specified the default value from ``InfluxDBClient.org`` is used.
        :param dialect: csv dialect format
        :param params: bind parameters
        :return: str
        """
        org = self._org_param(org)
        result = self._query_api.post_query(org=org, query=self._create_query(query, dialect, params), async_req=False,
                                            _preload_content=False)

        return result

    def query(self, query: str, org=None, params: dict = None) -> TableList:
        """Execute synchronous Flux query and return result as a :class:`~influxdb_client.client.flux_table.FluxTable` list.

        :param query: the Flux query
        :param str, Organization org: specifies the organization for executing the query;
                                      Take the ``ID``, ``Name`` or ``Organization``.
                                      If not specified the default value from ``InfluxDBClient.org`` is used.
        :param params: bind parameters
        :return: :class:`~influxdb_client.client.flux_table.FluxTable` list wrapped into
                 :class:`~influxdb_client.client.flux_table.TableList`
        :rtype: TableList

        Serialization the query results to flattened list of values via :func:`~influxdb_client.client.flux_table.TableList.to_values`:

        .. code-block:: python

            from influxdb_client import InfluxDBClient

            with InfluxDBClient(url="http://localhost:8086", token="my-token", org="my-org") as client:

                # Query: using Table structure
                tables = client.query_api().query('from(bucket:"my-bucket") |> range(start: -10m)')

                # Serialize to values
                output = tables.to_values(columns=['location', '_time', '_value'])
                print(output)

        .. code-block:: python

            [
                ['New York', datetime.datetime(2022, 6, 7, 11, 3, 22, 917593, tzinfo=tzutc()), 24.3],
                ['Prague', datetime.datetime(2022, 6, 7, 11, 3, 22, 917593, tzinfo=tzutc()), 25.3],
                ...
            ]

        Serialization the query results to JSON via :func:`~influxdb_client.client.flux_table.TableList.to_json`:

        .. code-block:: python

            from influxdb_client import InfluxDBClient

            with InfluxDBClient(url="http://localhost:8086", token="my-token", org="my-org") as client:

                # Query: using Table structure
                tables = client.query_api().query('from(bucket:"my-bucket") |> range(start: -10m)')

                # Serialize to JSON
                output = tables.to_json(indent=5)
                print(output)

        .. code-block:: javascript

            [
                {
                    "_measurement": "mem",
                    "_start": "2021-06-23T06:50:11.897825+00:00",
                    "_stop": "2021-06-25T06:50:11.897825+00:00",
                    "_time": "2020-02-27T16:20:00.897825+00:00",
                    "region": "north",
                     "_field": "usage",
                    "_value": 15
                },
                {
                    "_measurement": "mem",
                    "_start": "2021-06-23T06:50:11.897825+00:00",
                    "_stop": "2021-06-25T06:50:11.897825+00:00",
                    "_time": "2020-02-27T16:20:01.897825+00:00",
                    "region": "west",
                     "_field": "usage",
                    "_value": 10
                },
                ...
            ]
        """  # noqa: E501
        org = self._org_param(org)

        response = self._query_api.post_query(org=org, query=self._create_query(query, self.default_dialect, params),
                                              async_req=False, _preload_content=False, _return_http_data_only=False)

        return self._to_tables(response, query_options=self._get_query_options())

    def query_stream(self, query: str, org=None, params: dict = None) -> Generator['FluxRecord', Any, None]:
        """
        Execute synchronous Flux query and return stream of FluxRecord as a Generator['FluxRecord'].

        :param query: the Flux query
        :param str, Organization org: specifies the organization for executing the query;
                                      Take the ``ID``, ``Name`` or ``Organization``.
                                      If not specified the default value from ``InfluxDBClient.org`` is used.
        :param params: bind parameters
        :return: Generator['FluxRecord']
        """
        org = self._org_param(org)

        response = self._query_api.post_query(org=org, query=self._create_query(query, self.default_dialect, params),
                                              async_req=False, _preload_content=False, _return_http_data_only=False)
        return self._to_flux_record_stream(response, query_options=self._get_query_options())

    def query_data_frame(self, query: str, org=None, data_frame_index: List[str] = None, params: dict = None,
                         use_extension_dtypes: bool = False):
        """
        Execute synchronous Flux query and return Pandas DataFrame.

        .. note:: If the ``query`` returns tables with differing schemas than the client generates a :class:`~DataFrame` for each of them.

        :param query: the Flux query
        :param str, Organization org: specifies the organization for executing the query;
                                      Take the ``ID``, ``Name`` or ``Organization``.
                                      If not specified the default value from ``InfluxDBClient.org`` is used.
        :param data_frame_index: the list of columns that are used as DataFrame index
        :param params: bind parameters
        :param use_extension_dtypes: set to ``True`` to use panda's extension data types.
                                     Useful for queries with ``pivot`` function.
                                     When data has missing values, column data type may change (to ``object`` or ``float64``).
                                     Nullable extension types (``Int64``, ``Float64``, ``boolean``) support ``panda.NA`` value.
                                     For more info, see https://pandas.pydata.org/docs/user_guide/missing_data.html.
        :return: :class:`~DataFrame` or :class:`~List[DataFrame]`

        .. warning:: For the optimal processing of the query results use the ``pivot() function`` which align results as a table.

            .. code-block:: text

                from(bucket:"my-bucket")
                    |> range(start: -5m, stop: now())
                    |> filter(fn: (r) => r._measurement == "mem")
                    |> pivot(rowKey:["_time"], columnKey: ["_field"], valueColumn: "_value")

            For more info see:
                - https://docs.influxdata.com/resources/videos/pivots-in-flux/
                - https://docs.influxdata.com/flux/latest/stdlib/universe/pivot/
                - https://docs.influxdata.com/flux/latest/stdlib/influxdata/influxdb/schema/fieldsascols/
        """  # noqa: E501
        _generator = self.query_data_frame_stream(query, org=org, data_frame_index=data_frame_index, params=params,
                                                  use_extension_dtypes=use_extension_dtypes)
        return self._to_data_frames(_generator)

    def query_data_frame_stream(self, query: str, org=None, data_frame_index: List[str] = None, params: dict = None,
                                use_extension_dtypes: bool = False):
        """
        Execute synchronous Flux query and return stream of Pandas DataFrame as a :class:`~Generator[DataFrame]`.

        .. note:: If the ``query`` returns tables with differing schemas than the client generates a :class:`~DataFrame` for each of them.

        :param query: the Flux query
        :param str, Organization org: specifies the organization for executing the query;
                                      Take the ``ID``, ``Name`` or ``Organization``.
                                      If not specified the default value from ``InfluxDBClient.org`` is used.
        :param data_frame_index: the list of columns that are used as DataFrame index
        :param params: bind parameters
        :param use_extension_dtypes: set to ``True`` to use panda's extension data types.
                                     Useful for queries with ``pivot`` function.
                                     When data has missing values, column data type may change (to ``object`` or ``float64``).
                                     Nullable extension types (``Int64``, ``Float64``, ``boolean``) support ``panda.NA`` value.
                                     For more info, see https://pandas.pydata.org/docs/user_guide/missing_data.html.
        :return: :class:`~Generator[DataFrame]`

        .. warning:: For the optimal processing of the query results use the ``pivot() function`` which align results as a table.

            .. code-block:: text

                from(bucket:"my-bucket")
                    |> range(start: -5m, stop: now())
                    |> filter(fn: (r) => r._measurement == "mem")
                    |> pivot(rowKey:["_time"], columnKey: ["_field"], valueColumn: "_value")

            For more info see:
                - https://docs.influxdata.com/resources/videos/pivots-in-flux/
                - https://docs.influxdata.com/flux/latest/stdlib/universe/pivot/
                - https://docs.influxdata.com/flux/latest/stdlib/influxdata/influxdb/schema/fieldsascols/
        """  # noqa: E501
        org = self._org_param(org)

        response = self._query_api.post_query(org=org, query=self._create_query(query, self.default_dialect, params,
                                                                                dataframe_query=True),
                                              async_req=False, _preload_content=False, _return_http_data_only=False)

        return self._to_data_frame_stream(data_frame_index=data_frame_index,
                                          response=response,
                                          query_options=self._get_query_options(),
                                          use_extension_dtypes=use_extension_dtypes)

    def __del__(self):
        """Close QueryAPI."""
        pass



# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401


class TemplateSummarySummaryNotificationRules(object):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'kind': 'TemplateKind',
        'template_meta_name': 'str',
        'name': 'str',
        'description': 'str',
        'endpoint_template_meta_name': 'str',
        'endpoint_id': 'str',
        'endpoint_type': 'str',
        'every': 'str',
        'offset': 'str',
        'message_template': 'str',
        'status': 'str',
        'status_rules': 'list[TemplateSummarySummaryStatusRules]',
        'tag_rules': 'list[TemplateSummarySummaryTagRules]',
        'label_associations': 'list[TemplateSummaryLabel]',
        'env_references': 'list[object]'
    }

    attribute_map = {
        'kind': 'kind',
        'template_meta_name': 'templateMetaName',
        'name': 'name',
        'description': 'description',
        'endpoint_template_meta_name': 'endpointTemplateMetaName',
        'endpoint_id': 'endpointID',
        'endpoint_type': 'endpointType',
        'every': 'every',
        'offset': 'offset',
        'message_template': 'messageTemplate',
        'status': 'status',
        'status_rules': 'statusRules',
        'tag_rules': 'tagRules',
        'label_associations': 'labelAssociations',
        'env_references': 'envReferences'
    }

    def __init__(self, kind=None, template_meta_name=None, name=None, description=None, endpoint_template_meta_name=None, endpoint_id=None, endpoint_type=None, every=None, offset=None, message_template=None, status=None, status_rules=None, tag_rules=None, label_associations=None, env_references=None):  # noqa: E501,D401,D403
        """TemplateSummarySummaryNotificationRules - a model defined in OpenAPI."""  # noqa: E501
        self._kind = None
        self._template_meta_name = None
        self._name = None
        self._description = None
        self._endpoint_template_meta_name = None
        self._endpoint_id = None
        self._endpoint_type = None
        self._every = None
        self._offset = None
        self._message_template = None
        self._status = None
        self._status_rules = None
        self._tag_rules = None
        self._label_associations = None
        self._env_references = None
        self.discriminator = None

        if kind is not None:
            self.kind = kind
        if template_meta_name is not None:
            self.template_meta_name = template_meta_name
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if endpoint_template_meta_name is not None:
            self.endpoint_template_meta_name = endpoint_template_meta_name
        if endpoint_id is not None:
            self.endpoint_id = endpoint_id
        if endpoint_type is not None:
            self.endpoint_type = endpoint_type
        if every is not None:
            self.every = every
        if offset is not None:
            self.offset = offset
        if message_template is not None:
            self.message_template = message_template
        if status is not None:
            self.status = status
        if status_rules is not None:
            self.status_rules = status_rules
        if tag_rules is not None:
            self.tag_rules = tag_rules
        if label_associations is not None:
            self.label_associations = label_associations
        if env_references is not None:
            self.env_references = env_references

    @property
    def kind(self):
        """Get the kind of this TemplateSummarySummaryNotificationRules.

        :return: The kind of this TemplateSummarySummaryNotificationRules.
        :rtype: TemplateKind
        """  # noqa: E501
        return self._kind

    @kind.setter
    def kind(self, kind):
        """Set the kind of this TemplateSummarySummaryNotificationRules.

        :param kind: The kind of this TemplateSummarySummaryNotificationRules.
        :type: TemplateKind
        """  # noqa: E501
        self._kind = kind

    @property
    def template_meta_name(self):
        """Get the template_meta_name of this TemplateSummarySummaryNotificationRules.

        :return: The template_meta_name of this TemplateSummarySummaryNotificationRules.
        :rtype: str
        """  # noqa: E501
        return self._template_meta_name

    @template_meta_name.setter
    def template_meta_name(self, template_meta_name):
        """Set the template_meta_name of this TemplateSummarySummaryNotificationRules.

        :param template_meta_name: The template_meta_name of this TemplateSummarySummaryNotificationRules.
        :type: str
        """  # noqa: E501
        self._template_meta_name = template_meta_name

    @property
    def name(self):
        """Get the name of this TemplateSummarySummaryNotificationRules.

        :return: The name of this TemplateSummarySummaryNotificationRules.
        :rtype: str
        """  # noqa: E501
        return self._name

    @name.setter
    def name(self, name):
        """Set the name of this TemplateSummarySummaryNotificationRules.

        :param name: The name of this TemplateSummarySummaryNotificationRules.
        :type: str
        """  # noqa: E501
        self._name = name

    @property
    def description(self):
        """Get the description of this TemplateSummarySummaryNotificationRules.

        :return: The description of this TemplateSummarySummaryNotificationRules.
        :rtype: str
        """  # noqa: E501
        return self._description

    @description.setter
    def description(self, description):
        """Set the description of this TemplateSummarySummaryNotificationRules.

        :param description: The description of this TemplateSummarySummaryNotificationRules.
        :type: str
        """  # noqa: E501
        self._description = description

    @property
    def endpoint_template_meta_name(self):
        """Get the endpoint_template_meta_name of this TemplateSummarySummaryNotificationRules.

        :return: The endpoint_template_meta_name of this TemplateSummarySummaryNotificationRules.
        :rtype: str
        """  # noqa: E501
        return self._endpoint_template_meta_name

    @endpoint_template_meta_name.setter
    def endpoint_template_meta_name(self, endpoint_template_meta_name):
        """Set the endpoint_template_meta_name of this TemplateSummarySummaryNotificationRules.

        :param endpoint_template_meta_name: The endpoint_template_meta_name of this TemplateSummarySummaryNotificationRules.
        :type: str
        """  # noqa: E501
        self._endpoint_template_meta_name = endpoint_template_meta_name

    @property
    def endpoint_id(self):
        """Get the endpoint_id of this TemplateSummarySummaryNotificationRules.

        :return: The endpoint_id of this TemplateSummarySummaryNotificationRules.
        :rtype: str
        """  # noqa: E501
        return self._endpoint_id

    @endpoint_id.setter
    def endpoint_id(self, endpoint_id):
        """Set the endpoint_id of this TemplateSummarySummaryNotificationRules.

        :param endpoint_id: The endpoint_id of this TemplateSummarySummaryNotificationRules.
        :type: str
        """  # noqa: E501
        self._endpoint_id = endpoint_id

    @property
    def endpoint_type(self):
        """Get the endpoint_type of this TemplateSummarySummaryNotificationRules.

        :return: The endpoint_type of this TemplateSummarySummaryNotificationRules.
        :rtype: str
        """  # noqa: E501
        return self._endpoint_type

    @endpoint_type.setter
    def endpoint_type(self, endpoint_type):
        """Set the endpoint_type of this TemplateSummarySummaryNotificationRules.

        :param endpoint_type: The endpoint_type of this TemplateSummarySummaryNotificationRules.
        :type: str
        """  # noqa: E501
        self._endpoint_type = endpoint_type

    @property
    def every(self):
        """Get the every of this TemplateSummarySummaryNotificationRules.

        :return: The every of this TemplateSummarySummaryNotificationRules.
        :rtype: str
        """  # noqa: E501
        return self._every

    @every.setter
    def every(self, every):
        """Set the every of this TemplateSummarySummaryNotificationRules.

        :param every: The every of this TemplateSummarySummaryNotificationRules.
        :type: str
        """  # noqa: E501
        self._every = every

    @property
    def offset(self):
        """Get the offset of this TemplateSummarySummaryNotificationRules.

        :return: The offset of this TemplateSummarySummaryNotificationRules.
        :rtype: str
        """  # noqa: E501
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Set the offset of this TemplateSummarySummaryNotificationRules.

        :param offset: The offset of this TemplateSummarySummaryNotificationRules.
        :type: str
        """  # noqa: E501
        self._offset = offset

    @property
    def message_template(self):
        """Get the message_template of this TemplateSummarySummaryNotificationRules.

        :return: The message_template of this TemplateSummarySummaryNotificationRules.
        :rtype: str
        """  # noqa: E501
        return self._message_template

    @message_template.setter
    def message_template(self, message_template):
        """Set the message_template of this TemplateSummarySummaryNotificationRules.

        :param message_template: The message_template of this TemplateSummarySummaryNotificationRules.
        :type: str
        """  # noqa: E501
        self._message_template = message_template

    @property
    def status(self):
        """Get the status of this TemplateSummarySummaryNotificationRules.

        :return: The status of this TemplateSummarySummaryNotificationRules.
        :rtype: str
        """  # noqa: E501
        return self._status

    @status.setter
    def status(self, status):
        """Set the status of this TemplateSummarySummaryNotificationRules.

        :param status: The status of this TemplateSummarySummaryNotificationRules.
        :type: str
        """  # noqa: E501
        self._status = status

    @property
    def status_rules(self):
        """Get the status_rules of this TemplateSummarySummaryNotificationRules.

        :return: The status_rules of this TemplateSummarySummaryNotificationRules.
        :rtype: list[TemplateSummarySummaryStatusRules]
        """  # noqa: E501
        return self._status_rules

    @status_rules.setter
    def status_rules(self, status_rules):
        """Set the status_rules of this TemplateSummarySummaryNotificationRules.

        :param status_rules: The status_rules of this TemplateSummarySummaryNotificationRules.
        :type: list[TemplateSummarySummaryStatusRules]
        """  # noqa: E501
        self._status_rules = status_rules

    @property
    def tag_rules(self):
        """Get the tag_rules of this TemplateSummarySummaryNotificationRules.

        :return: The tag_rules of this TemplateSummarySummaryNotificationRules.
        :rtype: list[TemplateSummarySummaryTagRules]
        """  # noqa: E501
        return self._tag_rules

    @tag_rules.setter
    def tag_rules(self, tag_rules):
        """Set the tag_rules of this TemplateSummarySummaryNotificationRules.

        :param tag_rules: The tag_rules of this TemplateSummarySummaryNotificationRules.
        :type: list[TemplateSummarySummaryTagRules]
        """  # noqa: E501
        self._tag_rules = tag_rules

    @property
    def label_associations(self):
        """Get the label_associations of this TemplateSummarySummaryNotificationRules.

        :return: The label_associations of this TemplateSummarySummaryNotificationRules.
        :rtype: list[TemplateSummaryLabel]
        """  # noqa: E501
        return self._label_associations

    @label_associations.setter
    def label_associations(self, label_associations):
        """Set the label_associations of this TemplateSummarySummaryNotificationRules.

        :param label_associations: The label_associations of this TemplateSummarySummaryNotificationRules.
        :type: list[TemplateSummaryLabel]
        """  # noqa: E501
        self._label_associations = label_associations

    @property
    def env_references(self):
        """Get the env_references of this TemplateSummarySummaryNotificationRules.

        :return: The env_references of this TemplateSummarySummaryNotificationRules.
        :rtype: list[object]
        """  # noqa: E501
        return self._env_references

    @env_references.setter
    def env_references(self, env_references):
        """Set the env_references of this TemplateSummarySummaryNotificationRules.

        :param env_references: The env_references of this TemplateSummarySummaryNotificationRules.
        :type: list[object]
        """  # noqa: E501
        self._env_references = env_references

    def to_dict(self):
        """Return the model properties as a dict."""
        result = {}

        for attr, _ in self.openapi_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Return the string representation of the model."""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`."""
        return self.to_str()

    def __eq__(self, other):
        """Return true if both objects are equal."""
        if not isinstance(other, TemplateSummarySummaryNotificationRules):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Return true if both objects are not equal."""
        return not self == other





# noinspection PyMethodMayBeStatic
class _BaseService(object):

    def __init__(self, api_client=None):
        """Init common services operation."""
        if api_client is None:
            raise ValueError("Invalid value for `api_client`, must be defined.")
        self.api_client = api_client
        self._build_type = None

    def _check_operation_params(self, operation_id, supported_params, local_params):
        supported_params.append('async_req')
        supported_params.append('_return_http_data_only')
        supported_params.append('_preload_content')
        supported_params.append('_request_timeout')
        supported_params.append('urlopen_kw')
        for key, val in local_params['kwargs'].items():
            if key not in supported_params:
                raise TypeError(
                    f"Got an unexpected keyword argument '{key}'"
                    f" to method {operation_id}"
                )
            local_params[key] = val
        del local_params['kwargs']

    def _is_cloud_instance(self) -> bool:
        if not self._build_type:
            self._build_type = self.build_type()
        return 'cloud' in self._build_type.lower()

    async def _is_cloud_instance_async(self) -> bool:
        if not self._build_type:
            self._build_type = await self.build_type_async()
        return 'cloud' in self._build_type.lower()

    def build_type(self) -> str:
        """
        Return the build type of the connected InfluxDB Server.

        :return: The type of InfluxDB build.
        """
        from influxdb_client import PingService
        ping_service = PingService(self.api_client)

        response = ping_service.get_ping_with_http_info(_return_http_data_only=False)
        return self.response_header(response, header_name='X-Influxdb-Build')

    async def build_type_async(self) -> str:
        """
        Return the build type of the connected InfluxDB Server.

        :return: The type of InfluxDB build.
        """
        from influxdb_client import PingService
        ping_service = PingService(self.api_client)

        response = await ping_service.get_ping_async(_return_http_data_only=False)
        return self.response_header(response, header_name='X-Influxdb-Build')

    def response_header(self, response, header_name='X-Influxdb-Version') -> str:
        if response is not None and len(response) >= 3:
            if header_name in response[2]:
                return response[2][header_name]

        return "unknown"
